#|

  This is a dialog to create a die bushing at selected location.  
  Set up to give user default choices.

  16-Dec-1999  Added code to allow multiple locations.  Creates shared
               parts with similar names for locations 2 thru n.

|#

;; Last modified  : 16-Dec-1999
;; Category       : Parts
;; Author         : Bruce Fisher (bfisher@lhcarbide.com)
;; Company        : L.H. Carbide Corporation
;; Macro Purpose  : Create a die bushing with back taper
;; Filename       : mk_bshg_a.lsp
;; SD Revision	: 7.11,7.51
;; Macro Revision	: 2.00
;; Platform       : Windows NT 4.0
;; Video Mode        :  Native
;; Monitor Resolution:  1280x1024

(in-package :LHC)
(use-package :OLI)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; Calls function "make_bshg"

(sd-defdialog 'lhc_mk_bshg
  :dialog-title "Die Bushing"
  :variables
  '((POINT_LIST)
    (A_PART 
            :value-type :part-incl-new
	      :modifies :contents 
	      :title "Part"
	      :prompt-text "Identify part to install bushing."
    )

    (A_WP   
            :value-type :wp 
	      :title "Workplane"
	      :prompt-text "Identify workplane."
    )

    (A_ASM   
            :value-type :assembly 
	      :modifies :contents 
	      :title "Assembly"
	      :prompt-text "Select Assembly."
    )

    (B_NAME   
            :value-type :string 
	      :title "Bshg Name"
            :initial-value "bshg_new"
	      :prompt-text "Enter bushing name."
    )

    (PNT_1  
            :value-type :point-3d-pick
            :title "Location"
            :prompt-text "Enter location for bushing."
            :after-input 
              (progn
              (push-point pnt_1)
              (sd-call-cmds (c_point pnt_1))
              )
    )

    (PNT_2)
    (OUT_DIA 
            :title "Outer Dia."
            :range (.1875 .2500 .3125 .3750 .4375 .5000 .6250 .7500 .8750 1.0000)
            :after-input
              (case OUT_DIA
                 (.1875 (setq IN_DIA .090))
                 (.2500 (setq IN_DIA .1409))
                 (.3125 (setq IN_DIA .1609))
                 (.3750 (setq IN_DIA .1909))
                 (.4375 (setq IN_DIA .3000))
                 (.5000 (setq IN_DIA .3009))
                 (.6250 (setq IN_DIA .3809))
                 (.7500 (setq IN_DIA .5100))
                 (.8750 (setq IN_DIA .5150))
                 (1.0000 (setq IN_DIA .6750))))

    (IN_DIA 
            :value-type :positive-number
            :title "Inner Dia."
            :initial-value .090  ; Matches initial OD of .1875
            :prompt-text "Enter I.D."
    )

    (B_DPTH 
            :value-type :positive-number
            :title "Length"
            :initial-value 1.25 ; Normal thickness of die steel
            :prompt-text "Enter bushing length"
    )

   (MACH_OP
            :initial-value 1
   )
    (INC_NUM   
            :value-type :integer
            :toggle-type :invisible
	      :initial-value 0
    )

    (NEW_PRT_NM
            :initial-value "New_copy"
    )     

    (NM_ADD)

    (TMP_SEL)

    (TMP_NM)

    (O_PRT)

    ("-")

   (BACK 
         :push-action (pop-point)
   )
  )
  :local-functions

     '((PUSH-POINT (a-new-point)
         (push a-new-point point_list)
      )
      (POP-POINT ()
         (pop point_list)
         (unless point_list
           (sd-set-variable-status 'back :enable nil)))

       (BSHG-MAKE ()
         (punch_hl a_part pnt_1 out_dia) ;make hole .0001 smaller
         (make_bshg a_part pnt_1 b_dpth (+ out_dia .0001) in_dia a_asm b_name)
       )

       (MAIN-ACTION ()
         (progn
         (bshg-make)
         (setq o_prt b_name)
         (setq tmp_nm (sd-inq-obj-pathname a_asm))
         (setq t2 (concatenate 'string tmp_nm "/" b_name))
         (setq tmp_sel (sd-pathname-to-obj t2))

         (pop point_list)
         (when point_list
         (progn
         (dolist (pnt_2 point_list)   ;make shared copies of bshg
         (multi-bshg pnt_1 pnt_2))

         (dolist (pnt_2 point_list)   ;machine holes for copies
         (bshg_hl_cp pnt_2))
         (current_part a_part)
          )
          )
       ))

       (BSHG_HL_CP (p_2)
         (punch_hl a_part p_2 out_dia) ;make hole .0001 smaller
       )

      (MULTI-BSHG (pt_1 pt_2)
         (progn
         (setq inc_num (+ inc_num 1))
         (setq nm_add (sd-num-to-string inc_num))
         (setq new_prt_nm (concatenate 'string o_prt "." nm_add))
         (sd-call-cmds (create_multiple_pa 
                            :share
                            :source tmp_sel
                            :name new_prt_nm
                            :owner a_asm
                            :keep_attr :on
                            :translate :two_ptv pt_1 pt_2)
          ))
      ) 
  )

  :ok-action
  '(main-action))
